@@ -4,7 +4,7 @@ import json
 #This is the number of attemps that will be attempted before the request fails
 totalAttempts = 3
 
-#Not much error handling in this so always use proper capitalization when using any method
+#Not much error handling in this so always use proper capitalization when calling any method
 
 
 class Firebot:
@@ -14,7 +14,7 @@ class Firebot:
         self.url = url
 
 
-    def get_status(self):
+    def getStatus(self):
         """
         Returns a True of False based on the connection status of firebot 
         """
@@ -22,7 +22,7 @@ class Firebot:
         return bool(r.json()['connections']['chat'])
     
 
-    def get_effects(self):
+    def getEffects(self):
         """
         Returns a list with all the effects within firebot
         """
@@ -44,7 +44,7 @@ class Firebot:
                 attempts += 1
 
 
-    def get_presetEffectID(self, name):
+    def getPresetEffectID(self, name):
         """
         Returns the ID of a preset effect list.
         """
@@ -56,7 +56,7 @@ class Firebot:
                 return effect['id']
 
 
-    def get_allPresetEffects(self):
+    def getAllPresetEffects(self):
         """
         Returns all the preset effects currently in firebot
         """
@@ -69,7 +69,7 @@ class Firebot:
                 attempts += 1
                 
 
-    def get_allViewers(self):
+    def getAllViewers(self):
         """
         Returns a list of all the users stored in firebots database
         """
@@ -82,22 +82,22 @@ class Firebot:
                 attempts += 1
 
 
-    def get_viewerID(self, user):
+    def getViewerID(self, user):
         """
         Returns a the id associated with a user in firebots database
         """
-        data = self.get_allViewers()
+        data = self.getAllViewers()
         for x in data:
             username = x['username'].lower()
             if username == user.lower():
                 return x['id']
 
 
-    def get_allUserMetadata(self, user):
+    def getAllUserMetadata(self, user):
         """
         Returns all the metadata from firebots database
         """
-        id = self.get_viewerID(user)
+        id = self.getViewerID(user)
         if id != None:
             attempts = 0
             while attempts <= totalAttempts:
@@ -110,7 +110,7 @@ class Firebot:
             return None
 
 
-    def get_userMetadata(self, user, metadata):
+    def getUserMetadata(self, user, metadata):
         """
         Returns the value of metadata for a user. Metadata postional argument is case sensitive. 
         """
@@ -119,7 +119,7 @@ class Firebot:
             attempts = 0
             while attempts <= totalAttempts:
                 try:
-                    data = self.get_allUserMetadata(user)
+                    data = self.getAllUserMetadata(user)
                     return data['metadata'][metadata]
                 except:
                     attempts += 1
@@ -127,7 +127,7 @@ class Firebot:
             return None
 
 
-    def get_allCurrencyID(self):
+    def getAllCurrencyID(self):
         """
         Returns a list of all the currency ID's stored in firebots database
         """
@@ -140,21 +140,21 @@ class Firebot:
                 attempts += 1
 
 
-    def get_currencyID(self, currency):
+    def getCurrencyID(self, currency):
         """
         Returns the currency ID of the given currency
         """
-        data = self.get_allCurrencyID()
+        data = self.getAllCurrencyID()
         for x in data:
             if currency == data[x]['name']:
                 return data[x]['id']
 
 
-    def get_topCurrency(self, currency, count = 10):
+    def getTopCurrency(self, currency, count = 10):
         """
         Returns a list of the users with the top amount in a currency. Defaults to 10.
         """
-        id = self.get_currencyID(currency)
+        id = self.getCurrencyID(currency)
         if id != None:
             attempts = 0
             while attempts <= totalAttempts:
@@ -172,7 +172,7 @@ class Firebot:
                     attempts += 1
 
 
-    def get_userCurrency(self, user, currency):
+    def getUserCurrency(self, user, currency):
         """
         Returns the amount a user has of the given currency
         """
@@ -187,11 +187,11 @@ class Firebot:
                     attempts += 1
 
 
-    def set_userCurrency(self, user, currency, amount):
+    def setUserCurrency(self, user, currency, amount):
         """
         Sets the currency amount for a user
         """
-        id = self.get_currencyID(currency)
+        id = self.getCurrencyID(currency)
         data = {
             "effects": {
                 "list": [
@@ -210,7 +210,7 @@ class Firebot:
             return self.post(data)
 
 
-    def get_allVariables(self):
+    def getAllVariables(self):
         """
         Returns the value of all variables stored in firebots database. DO NOT RECOMMEND RUNNING THIS AS IT IS A LOT OF DATA
         """
@@ -224,7 +224,7 @@ class Firebot:
                     attempts += 1
 
 
-    def get_variable(self, variable):
+    def getVariable(self, variable):
         """
         Returns the value of a variable stored in firebots database
         """
@@ -238,38 +238,38 @@ class Firebot:
                     attempts += 1
 
 
-    def get_userRoles(self, user):
+    def getUserRoles(self, user):
         """
         Returns a list of roles the user is assigned to
         """
         role_list = []
-        for role in self.get_allUserMetadata(user)['customRoles']:
+        for role in self.getAllUserMetadata(user)['customRoles']:
             role_list.append(role['name'])
         return role_list
 
 
-    def get_userProfilePic(self, user):
+    def getUserProfilePic(self, user):
         """
         Returns the link to the users profile pic
         """
-        return self.get_allUserMetadata(user)['profilePicUrl']
+        return self.getAllUserMetadata(user)['profilePicUrl']
 
 
-    def get_userModStatus(self, user):
+    def getUserModStatus(self, user):
         """
         Returns either a True or False if the user is assigned as a mod
         """
-        if 'mod' in self.get_allUserMetadata(user)['twitchRoles']:
+        if 'mod' in self.getAllUserMetadata(user)['twitchRoles']:
             return True
         else:
             return False
 
 
-    def add_currency(self, currency, amount, username):
+    def addCurrency(self, currency, amount, username):
         """
         Add currency to a user.
         """
-        currencyid = self.get_currencyID(currency)
+        currencyid = self.getCurrencyID(currency)
         data = {
             "effects": {
                 "list": [
@@ -291,7 +291,7 @@ class Firebot:
         """
         Subtracts currency from a user.
         """
-        currencyid = self.get_currencyID(currency)
+        currencyid = self.getCurrencyID(currency)
         data = {
             "effects": {
                 "list": [
@@ -400,7 +400,7 @@ class Firebot:
 
     def changeObsScene(self, scene):
         """
-        Change scenes in OBS. Must have the custom script installed
+        Change scenes in OBS.
         """
         data = {
             "effects": {
@@ -416,6 +416,40 @@ class Firebot:
         self.post(data)
 
 
+    def startStream(self):
+        """
+        Starts streaming in OBS
+        """
+        data = {
+            "effects": {
+                "list": [
+                    {
+                        "type": "ebiggz:obs-start-stream",
+                        "active": "true",
+                    }
+                ]
+            }
+        }
+        self.post(data)
+
+
+    def stopStream(self):
+        """
+        Stops streaming in OBS
+        """
+        data = {
+            "effects": {
+                "list": [
+                    {
+                        "type": "ebiggz:obs-stop-stream",
+                        "active": "true",
+                    }
+                ]
+            }
+        }
+        self.post(data)
+
+
     def setMetadata(self, key, data, username):
         """
         Set the metadata for a user.
@@ -814,7 +848,7 @@ class Firebot:
         self.post(data)
 
 
-    def get_quotes(self):
+    def getQuotes(self):
         """
         Returns a list of all the quotes stored in firebots database
         """
@@ -847,3 +881,304 @@ class Firebot:
         }
         self.post(data)
 
+
+    def getCounters(self):
+        """
+        Returns a list of all the counters
+        """
+        attempts = 0
+        while attempts <= totalAttempts:
+            try:
+                r = requests.get(self.url+f"/counters")
+                return r.json()
+            except:
+                attempts += 1
+    
+
+    def getCounterID(self, counterName):
+        counters = self.getCounters()
+        for counter in counters:
+            if counter['name'] == counterName:
+                return counter['id']
+
+
+    def getCounterValue(self, counterName):
+        """
+        Returns the value of a counter
+        """
+        counters = self.getCounters()
+        for counter in counters:
+            if counterName == counter['name']:
+                return int(counter['value'])
+
+
+    def increaseCounter(self, counterName, amount):
+        """
+        Increases a counter by a value
+        """
+        id = self.getCounterID(counterName)
+        data = {
+            "effects": {
+                "list": [
+                    {
+                        "type": "firebot:update-counter",
+                        "value": amount,
+                        "counterId": id,
+                        "mode": "increment",
+                        "active": "true",
+                    }
+                ]
+            }
+        }
+        self.post(data)
+
+
+    def setCounter(self, counterName, amount):
+        """
+        Sets a counter to a value
+        """
+        id = self.getCounterID(counterName)
+        data = {
+            "effects": {
+                "list": [
+                    {
+                        "type": "firebot:update-counter",
+                        "value": amount,
+                        "counterId": id,
+                        "mode": "set",
+                        "active": "true",
+                    }
+                ]
+            }
+        }
+        self.post(data)
+
+
+    def getTimers(self):
+        """
+        Returns a list of all the timers
+        """
+        attempts = 0
+        while attempts <= totalAttempts:
+            try:
+                r = requests.get(self.url+f"/timers")
+                return r.json()
+            except:
+                attempts += 1
+
+
+    def getTimerID(self, timerName):
+        timers = self.getTimers()
+        for timer in timers:
+            if timer['name'] == timerName:
+                return timer['id']
+
+
+    def disableTimer(self, timerName):
+        """
+        Disables a timer
+        """
+        id = self.getTimerID(timerName)
+        print(id)
+        data = {
+            "effects": {
+                "list": [
+                    {
+                        "type": "firebot:toggle-timer",
+                        "selectedTimerId": id,
+                        "toggleType": "disable",
+                    }
+                ]
+            }
+        }
+        self.post(data)
+
+
+    def enableTimer(self, timerName):
+        """
+        Enables a timer
+        """
+        id = self.getTimerID(timerName)
+        print(id)
+        data = {
+            "effects": {
+                "list": [
+                    {
+                        "type": "firebot:toggle-timer",
+                        "selectedTimerId": id,
+                        "toggleType": "enable",
+                    }
+                ]
+            }
+        }
+        self.post(data)
+
+
+    def resetTimer(self, timerName):
+        """
+        Resets a timer
+        """
+        id = self.getTimerID(timerName)
+        print(id)
+        data = {
+            "effects": {
+                "list": [
+                    {
+                        "type": "firebot:reset-timer",
+                        "selectedTimerId": id,
+                        "active": "true",
+                    }
+                ]
+            }
+        }
+        self.post(data)
+
+
+    def getRoles(self):
+        """
+        Returns a list of all the roles
+        """
+        attempts = 0
+        while attempts <= totalAttempts:
+            try:
+                r = requests.get(self.url+f"/customroles")
+                return r.json()
+            except:
+                attempts += 1
+
+
+    def getRoleID(self, role):
+        """
+        Returns the role id
+        """
+        roles = self.getRoles()
+        for x in roles:
+            if x['name'] == role:
+                return x['id']
+
+
+    def checkRole(self, roleName, user):
+        """
+        Returns True if the user is in the role or False if they are not assigned to the role
+        """
+        status = False
+        roles = self.getRoles()
+        viewers = []
+        for role in roles:
+            if role['name'] == roleName:
+                for users in role['viewers']:
+                    viewers.append(users)
+        for users in viewers:
+            if user == users or user.lower() == users.lower():
+                status = True
+        return status
+
+
+    def assignRole(self, user, role):
+        """
+        Assigns a user to a role
+        """
+        roleid = self.getRoleID(role)
+        data = {
+            "effects": {
+                "list": [
+                    {
+                    "type": "firebot:update-roles",
+                    "viewerType": "custom",
+                    "addRoleId": roleid,
+                    "customViewer": user,
+                    "active": "true",
+                    }
+                ]
+            }
+        }
+        self.post(data)
+
+
+    def removeRole(self, user, role):
+        """
+        Removes a user from a role
+        """
+        roleid = self.getRoleID(role)
+        data = {
+            "effects": {
+                "list": [
+                    {
+                    "type": "firebot:update-roles",
+                    "viewerType": "custom",
+                    "removeRoleId": roleid,
+                    "customViewer": user,
+                    "active": "true",
+                    }
+                ]
+            }
+        }
+        self.post(data)
+
+
+    def removeAllRole(self, role):
+        """
+        Removes all users from a role
+        """
+        roleid = self.getRoleID(role)
+        data = {
+            "effects": {
+                "list": [
+                    {
+                    "type": "firebot:update-roles",
+                    "viewerType": "current",
+                    "removeAllRoleId": roleid,
+                    "active": "true",
+                    }
+                ]
+            }
+        }
+        self.post(data)
+
+
+    def textToSpeech(self, message):
+        """
+        Have firebot read out some text
+        """
+        data = {
+            "effects": {
+                "list": [
+                    {
+                    "type": "firebot:text-to-speech",
+                    "active": "true",
+                    "voiceId": "default",
+                    "text": message,
+                    }
+                ]
+            }
+        }
+        self.post(data)
+
+
+    def getSystemCommands(self):
+        """
+        Returns a list of all the system commands
+        """
+        attempts = 0
+        while attempts <= totalAttempts:
+            try:
+                r = requests.get(self.url+f"/commands/system")
+                return r.json()
+            except:
+                attempts += 1
+
+
+    def getCustomCommands(self):
+        """
+        Returns a list of all the custom commands
+        """
+        attempts = 0
+        while attempts <= totalAttempts:
+            try:
+                r = requests.get(self.url+f"/commands/custom")
+                return r.json()
+            except:
+                attempts += 1
+
+api = Firebot(url='http://192.168.0.35:7472/api/v1')
+print(api.getCustomCommands())
\ No newline at end of file
